@@ -4,7 +4,7 @@
  * GChemPaint library
  * atom.cc
  *
- * Copyright (C) 2001-2011 Jean Bréfort <jean.brefort@normalesup.org>
+ * Copyright (C) 2001-2012 Jean Bréfort <jean.brefort@normalesup.org>
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License as
@@ -1636,4 +1636,13 @@ bool Atom::HasStereoBond () const
 	return false;
 }
 
+Bond *Atom::GetNewmanBond () const
+{
+	std::map < gcu::Atom *, gcu::Bond * >::const_iterator i, end = m_Bonds.end ();
+	for (i = m_Bonds.begin (); i != end; i++)
+		if (static_cast < Bond * > ((*i).second)->GetType () == NewmanBondType)
+			return static_cast < Bond * > ((*i).second);
+	return NULL;
+}
+
 }	//	namespace gcp
