@@ -1,13 +1,13 @@
 // -*- C++ -*-
 
-/* 
+/*
  * GChemPaint library
- * bond.cc 
+ * bond.cc
  *
- * Copyright (C) 2001-2011 Jean Bréfort <jean.brefort@normalesup.org>
+ * Copyright (C) 2001-2012 Jean Bréfort <jean.brefort@normalesup.org>
  *
- * This program is free software; you can redistribute it and/or 
- * modify it under the terms of the GNU General Public License as 
+ * This program is free software; you can redistribute it and/or
+ * modify it under the terms of the GNU General Public License as
  * published by the Free Software Foundation; either version 2 of the
  * License, or (at your option) any later version.
  *
@@ -33,6 +33,7 @@
 #include "view.h"
 #include "widgetdata.h"
 #include <gccv/canvas.h>
+#include <gccv/circle.h>
 #include <gccv/group.h>
 #include <gccv/hash.h>
 #include <gccv/line.h>
@@ -40,6 +41,7 @@
 #include <gccv/wedge.h>
 #include <gcu/cycle.h>
 #include <gcu/objprops.h>
+#include <gcu/xml-utils.h>
 #include <gcugtk/ui-manager.h>
 #include <glib/gi18n-lib.h>
 #include <cmath>
@@ -62,7 +64,6 @@ Bond::Bond (Atom* first, Atom* last, unsigned char order):
 		gcu::Bond (first, last, order), ItemClient (), m_type (NormalBondType)
 {
 	m_CoordsCalc = false;
-//	m_type = NormalBondType;
 	m_level = 0;
 }
 
@@ -74,8 +75,21 @@ void Bond::SetType (BondType type)
 {
 	m_type = type;
 	m_CoordsCalc = false;
-	if (m_type != NormalBondType)
+	if (m_type != NormalBondType && m_type != NewmanBondType)
 		m_order = 1;
+	if (m_type == NewmanBondType) {
+		if (m_Begin && m_End) {
+			gcu::Atom *atom = m_Begin->z () > m_End->z ()? m_End: m_Begin;
+			std::map < gcu::Atom *, gcu::Bond * >::iterator i;
+			for (Bond *bond = static_cast < Bond * > (atom->GetFirstBond (i)); bond; bond = static_cast <Bond * > (atom->GetNextBond (i)))
+				 bond->m_CoordsCalc = false;
+		}
+		Document *doc = static_cast < Document * > (GetDocument ());
+		if (doc != NULL)
+			m_coords[15] = doc->GetBondLength () / 3.;
+		else
+			m_coords[15] = go_nan;
+	}
 }
 
 double Bond::GetAngle2D (Atom* pAtom)
@@ -100,49 +114,69 @@ bool Bond::GetLine2DCoords (unsigned Num, double* x1, double* y1, double* x2, do
 	if ((Num == 0) || (Num > m_order))
 		return false;
 	if (!m_CoordsCalc) {
-		Theme *Theme = dynamic_cast <Document *> (GetDocument ())->GetTheme ();
+		Document *doc = dynamic_cast < Document * > (GetDocument ());
+		Theme *Theme = doc->GetTheme ();
 		m_Begin->GetCoords (x1, y1);
 		m_End->GetCoords (x2, y2);
 		double dx = *x2 - *x1, dy = *y2 - *y1;
 		double l = sqrt (square (dx) + square (dy));
 		double BondDist = Theme->GetBondDist () / Theme->GetZoomFactor ();
+		double bl;
 		dx *= (BondDist / l);
 		dy *= (BondDist / l);
 		// now, exclude symbols rectangles from the drawing
 		double ax, ay, anga, angb = atan2 (fabs (dy), fabs (dx));
-		static_cast <Atom *> (m_Begin)->GetSymbolGeometry (ax, ay, anga, dy < 0);
 		bool horizontal;
-		if (ax > 0) {
-			horizontal = anga >= angb;
-			if (horizontal) {
-				ax = (ax + 1.) / Theme->GetZoomFactor ();
-				if (dx > 0)
-					ax = - ax;
-				*x1 -= ax;
-				*y1 -= ax * dy / dx;
-			} else {
-				ay = (ay + 1.) / Theme->GetZoomFactor ();
-				if (dy > 0)
-					ay = - ay;
-				*y1 -= ay;
-				*x1 -= ay * dx / dy;
+		gcp::Bond *bond = static_cast < Atom * > (m_Begin)->GetNewmanBond ();
+		if (bond != NULL && m_Begin->z () < bond->GetAtom (m_Begin)->z ()) {
+			bl = bond->m_coords[15];
+			if (!go_finite (bl))
+				return false;
+			*x1 += (*x2 - *x1) / l * bl;
+			*y1 += (*y2 - *y1) / l * bl;
+		} else {
+			static_cast < Atom * > (m_Begin)->GetSymbolGeometry (ax, ay, anga, dy < 0);
+			if (ax > 0) {
+				horizontal = anga >= angb;
+				if (horizontal) {
+					ax = (ax + 1.) / Theme->GetZoomFactor ();
+					if (dx > 0)
+						ax = - ax;
+					*x1 -= ax;
+					*y1 -= ax * dy / dx;
+				} else {
+					ay = (ay + 1.) / Theme->GetZoomFactor ();
+					if (dy > 0)
+						ay = - ay;
+					*y1 -= ay;
+					*x1 -= ay * dx / dy;
+				}
 			}
 		}
-		static_cast <Atom *> (m_End)->GetSymbolGeometry (ax, ay, anga, dy > 0);
-		if (ax > 0) {
-			horizontal = anga >= angb;
-			if (horizontal) {
-				ax = (ax + 1.) / Theme->GetZoomFactor ();
-				if (dx > 0)
-					ax = - ax;
-				*x2 += ax;
-				*y2 += ax * dy / dx;
-			} else {
-				ay = (ay + 1.) / Theme->GetZoomFactor ();
-				if (dy > 0)
-					ay = - ay;
-				*y2 += ay;
-				*x2 += ay * dx / dy;
+		bond = static_cast < Atom * > (m_End)->GetNewmanBond ();
+		if (bond != NULL && m_End->z () < bond->GetAtom (m_End)->z ()) {
+			bl = bond->m_coords[15];
+			if (!go_finite (bl))
+				return false;
+			*x2 -= (*x2 - *x1) / l * bl;
+			*y2 -= (*y2 - *y1) / l * bl;
+		} else {
+			static_cast <Atom *> (m_End)->GetSymbolGeometry (ax, ay, anga, dy > 0);
+			if (ax > 0) {
+				horizontal = anga >= angb;
+				if (horizontal) {
+					ax = (ax + 1.) / Theme->GetZoomFactor ();
+					if (dx > 0)
+						ax = - ax;
+					*x2 += ax;
+					*y2 += ax * dy / dx;
+				} else {
+					ay = (ay + 1.) / Theme->GetZoomFactor ();
+					if (dy > 0)
+						ay = - ay;
+					*y2 += ay;
+					*x2 += ay * dx / dy;
+				}
 			}
 		}
 		// always set the first line coords, even if changed later
@@ -226,7 +260,7 @@ general:
 								a = tan ((bond->GetAngle2DRad (static_cast <Atom*> (m_End)) - a0) / 2);
 								if (sign * a < sign * tanb)
 									tanb = a;
-								
+
 							}
 							bond = static_cast <Bond*> (m_End->GetNextBond (it));
 						}
@@ -254,7 +288,7 @@ general:
 									a = tan ((bond->GetAngle2DRad (static_cast <Atom*> (m_Begin)) - a2) / 2);
 									if (sign * a < sign * tanb)
 										tanb = a;
-									
+
 								}
 								bond = static_cast <Bond*> (m_Begin->GetNextBond (it));
 							}
@@ -280,7 +314,7 @@ general:
 									tana = a;
 								if (a < tanb)
 									tanb = a;
-								
+
 							}
 							bond = static_cast <Bond*> (m_Begin->GetNextBond (it));
 						}
@@ -294,7 +328,7 @@ general:
 									tanc = a;
 								if (a < tand)
 									tand = a;
-								
+
 							}
 							bond = static_cast <Bond*> (m_End->GetNextBond (it));
 						}
@@ -387,6 +421,10 @@ bool Bond::SaveNode (G_GNUC_UNUSED xmlDocPtr xml, xmlNodePtr node) const
 	case UndeterminedBondType:
 		xmlNewProp (node, (xmlChar*) "type", (xmlChar*) "undetermined");
 		break;
+	case NewmanBondType:
+		xmlNewProp (node, (xmlChar*) "type", (xmlChar*) "newman");
+		gcu::WriteFloat (node, "radius", m_coords[15]);
+		break;
 	default:
 		break;
 	}
@@ -412,6 +450,8 @@ bool Bond::LoadNode (xmlNodePtr node)
 		SetType (ForeBondType);
 	else if (!strcmp (buf, "undetermined"))
 		SetType (UndeterminedBondType);
+	else if (!strcmp (buf, "newman"))
+		SetType (NewmanBondType);
 	else
 		SetType (NormalBondType);
 	if (buf)
@@ -421,6 +461,9 @@ bool Bond::LoadNode (xmlNodePtr node)
 		m_level = atoi (buf);
 		xmlFree (buf);
 	}
+	if (m_type == NewmanBondType)
+		// don't care if there is no radius property
+		gcu::ReadFloat (node, "radius", m_coords[15], static_cast < Document * > (GetDocument ())->GetBondLength ());
 	return true;
 }
 
@@ -525,7 +568,7 @@ void Bond::SetSelected (int state)
 	if (!m_order || !m_Item)
 		return;
 	GOColor color;
-	switch (state) {	
+	switch (state) {
 	case SelStateUnselected:
 		color = Color;
 		break;
@@ -555,6 +598,7 @@ void Bond::SetSelected (int state)
 		break;
 	}
 	case UndeterminedBondType:
+	case NewmanBondType:
 	case ForeBondType: {
 		gccv::LineItem *item = static_cast <gccv::LineItem *> (m_Item);
 		item->SetLineColor (color);
@@ -675,6 +719,17 @@ void Bond::AddItem ()
 		m_Item = hash;
 		break;
 	}
+	case NewmanBondType: {
+		m_Begin->GetCoords (&x1, &y1);
+		gccv::Circle *circle = new gccv::Circle (view->GetCanvas ()->GetRoot (),
+		                                         x1 * theme->GetZoomFactor (),
+		                                         y1 * theme->GetZoomFactor (),
+		                                         m_coords[15] * theme->GetZoomFactor (),
+		                                         this);
+		circle->SetFillColor (0);
+		circle->SetLineColor ((view->GetData ()->IsSelected (this))? SelectColor: Color);
+		m_Item = circle;
+	}
 	}
 }
 
@@ -686,7 +741,7 @@ void Bond::UpdateItem ()
 	}
 	AddItem ();
 }
-	
+
 double Bond::GetYAlign ()
 {
 	double x1, y1, x2, y2;
@@ -960,6 +1015,10 @@ void Bond::OnLoaded ()
 		obj->SetDirty ();
 	} else
 		GetParent ()->SetDirty ();
+	if (m_type == NewmanBondType && m_Begin && m_End) {
+		// ensure begin and end are at the same x,y position
+		m_End->SetCoords (m_Begin->x (), m_Begin->y (), m_End->z ());
+	}
 }
 
 }	//	namespace gcp
