@@ -1,11 +1,11 @@
-/* 
+/*
  * GChemPaint library
  * window.cc
  *
  * Copyright (C) 2006-2011 Jean Bréfort <jean.brefort@normalesup.org>
  *
- * This program is free software; you can redistribute it and/or 
- * modify it under the terms of the GNU General Public License as 
+ * This program is free software; you can redistribute it and/or
+ * modify it under the terms of the GNU General Public License as
  * published by the Free Software Foundation; either version 2 of the
  * License, or (at your option) any later version.
  *
@@ -35,6 +35,7 @@
 #include <gcugtk/filechooser.h>
 #include <gcugtk/print-setup-dlg.h>
 #include <gcugtk/ui-manager.h>
+#include <gcugtk/stringinputdlg.h>
 #include <gcu/matrix.h>
 #include <gsf/gsf-input-memory.h>
 #include <glib/gi18n-lib.h>
@@ -44,82 +45,49 @@ using namespace gcu;
 
 namespace gcp {
 
-typedef void (*StringInputCB) (Target *obj, char const *str);
-
-class StringInput: public gcugtk::Dialog
-{
-public:
-	StringInput (Target *target, StringInputCB cb, char const *title);
-	virtual ~StringInput ();
-
-	bool Apply ();
-
-private:
-	Target *m_Target;
-	StringInputCB m_CB;
-};
-
-StringInput::StringInput (Target *target, StringInputCB cb, char const *title):
-	gcugtk::Dialog (target->GetApplication (), UIDIR"/stringinputdlg.ui", "string-input", GETTEXT_PACKAGE, target->GetDocument ()),
-	m_Target (target),
-	m_CB (cb)
-{
-	GtkWidget *w = GTK_WIDGET (gtk_builder_get_object (GetBuilder (), "string-input"));
-	gtk_window_set_title (GTK_WINDOW (w), title);
-	gtk_widget_show_all (w);
-}
-
-StringInput::~StringInput ()
-{
-}
-
-bool StringInput::Apply ()
-{
-	GtkEntry *entry = GTK_ENTRY (gtk_builder_get_object (GetBuilder (), "result"));
-	if (entry)
-		m_CB (m_Target, gtk_entry_get_text (entry)); 
-	return true;
-}
-
-class WindowPrivate {
+	class WindowPrivate {
 public:
 	static void ImportMolecule (G_GNUC_UNUSED GtkWidget* widget, gcp::Window* Win);
-	static void DoImportMol (Target *target, char const *str);
+	static void DoImportMol (gcu::Document *doc, char const *str);
 };
 
 void WindowPrivate::ImportMolecule (G_GNUC_UNUSED GtkWidget* widget, gcp::Window* Win)
 {
-	new StringInput (Win, &DoImportMol, _("Import moleculefrom InChI or SMILES"));
+	gcu::Dialog *dlg = Win->GetDocument ()->GetDialog ("string-input");
+	if (dlg)
+		dlg->Present ();
+	else
+		new gcugtk::StringInputDlg (Win->GetDocument (), &DoImportMol, _("Import molecule from InChI or SMILES"));
 }
 
-void WindowPrivate::DoImportMol (Target *target, char const *str)
+void WindowPrivate::DoImportMol (gcu::Document *doc, char const *str)
 {
 	if (!str || !*str)
 		return;
-	Application *app = target->GetApplication ();
-	Document *doc = target->GetDocument ();
+	Document *Doc = static_cast < Document * > (doc);
+	Application *app = Doc->GetApplication ();
 	GsfInput *input = gsf_input_memory_new (reinterpret_cast < guint8 const * > (str), strlen (str), false);
 	char *cml = app->ConvertToCML (input, ((!strncmp (str, "InChI=", 6))? "inchi": "smi"), "-c --gen2D");
 	g_object_unref (input);
 	if (!cml) // TODO: add an error message handler
 		return;
 	input = gsf_input_memory_new (reinterpret_cast < guint8 const * > (cml), strlen (cml), true);
-	app->Load (input, "chemical/x-cml", target->GetDocument (), NULL);
-	std::set < gcu::Object * > objs = static_cast < gcu::Document * > (doc)->GetNewObjects ();
-	doc->Loaded ();
+	app->Load (input, "chemical/x-cml", Doc, NULL);
+	std::set < gcu::Object * > objs = doc->GetNewObjects ();
+	Doc->Loaded ();
 	Molecule *mol = static_cast < Molecule * > ((*objs.begin ())->GetMolecule ());
 	// scale so that the mean bond length is correct
-	double l = mol->GetMeanBondLength (), l0 = doc->GetTheme ()->GetBondLength (), x0, y0, x1, y1;
+	double l = mol->GetMeanBondLength (), l0 = Doc->GetTheme ()->GetBondLength (), x0, y0, x1, y1;
 	l0 /= l;
 	Matrix2D m (l0, 0., 0., l0);
 	mol->Transform2D (m, 0., 0.);
 	// move to view center
-	doc->GetView ()->GetVisibleArea (x0, y0, x1, y1);
+	Doc->GetView ()->GetVisibleArea (x0, y0, x1, y1);
 	mol->Move ((x0 + x1) / 2., (y0 + y1) / 2.);
 	// show the molecule
-	doc->GetView ()->Update (mol);
+	Doc->GetView ()->Update (mol);
 	// mark the document as unsaved
-	doc->SetDirty ();
+	Doc->SetDirty ();
 	g_object_unref (input);
 }
 
@@ -536,11 +504,11 @@ static const char *ui_description =
 "	 <placeholder name='tools1'/>"
 "  </toolbar>"
 "</ui>";
-	
+
 Window::Window (gcp::Application *App, char const *Theme, char const *extra_ui) throw (std::runtime_error):
 	Target (App)
 {
-	GtkWidget *vbox;
+	GtkWidget *grid;
 	GtkWidget *bar;
 	GtkWindow *window;
 	GtkActionGroup *action_group;
@@ -553,28 +521,30 @@ Window::Window (gcp::Application *App, char const *Theme, char const *extra_ui)
 	g_object_set_data (G_OBJECT (window), "gcp-role", (void*) 1);
 	g_signal_connect (G_OBJECT (window), "destroy", G_CALLBACK (on_destroy), this);
 	g_signal_connect (G_OBJECT (window), "delete-event", G_CALLBACK (on_delete_event), this);
-	vbox = gtk_vbox_new (FALSE, 0);
-	gtk_container_add (GTK_CONTAINER (window), vbox);
+	grid = gtk_grid_new ();
+	g_object_set (G_OBJECT (grid), "orientation", GTK_ORIENTATION_VERTICAL, NULL);
+	gtk_container_add (GTK_CONTAINER (window), grid);
 	action_group = gtk_action_group_new ("MenuActions");
 	gtk_action_group_set_translation_domain (action_group, GETTEXT_PACKAGE);
 	gtk_action_group_add_actions (action_group, entries, G_N_ELEMENTS (entries), this);
 	gtk_action_group_add_toggle_actions (action_group, toggle_entries, G_N_ELEMENTS (toggle_entries), this);
 
 	m_UIManager = new gcugtk::UIManager (gtk_ui_manager_new ());
-	g_object_connect (m_UIManager->GetUIManager (),
+	GtkUIManager *manager = static_cast < gcugtk::UIManager * > (m_UIManager)->GetUIManager ();
+	g_object_connect (manager,
 		"signal::connect_proxy",    G_CALLBACK (on_connect_proxy), this,
 		"signal::disconnect_proxy", G_CALLBACK (on_disconnect_proxy), this,
 		NULL);
-	gtk_ui_manager_insert_action_group (m_UIManager->GetUIManager (), action_group, 0);
+	gtk_ui_manager_insert_action_group (manager, action_group, 0);
 	g_object_unref (action_group);
-	
+
 	error = NULL;
-	if (!gtk_ui_manager_add_ui_from_string (m_UIManager->GetUIManager (), ui_description, -1, &error)) {
+	if (!gtk_ui_manager_add_ui_from_string (manager, ui_description, -1, &error)) {
 		std::string what = std::string ("building menus failed: ") + error->message;
 		g_error_free (error);
 		throw std::runtime_error (what);
 	}
-	if (extra_ui && !gtk_ui_manager_add_ui_from_string (m_UIManager->GetUIManager (), extra_ui, -1, &error)) {
+	if (extra_ui && !gtk_ui_manager_add_ui_from_string (manager, extra_ui, -1, &error)) {
 		g_message ("building menus failed: %s", error->message);
 		g_error_free (error);
 	}
@@ -582,7 +552,7 @@ Window::Window (gcp::Application *App, char const *Theme, char const *extra_ui)
 	//  now add entries registered by plugins.
 	App->BuildMenu (m_UIManager);
 
-	accel_group = gtk_ui_manager_get_accel_group (m_UIManager->GetUIManager ());
+	accel_group = gtk_ui_manager_get_accel_group (manager);
 	gtk_window_add_accel_group (window, accel_group);
 
 	switch (App->GetDefaultWindowState ()) {
@@ -594,13 +564,13 @@ Window::Window (gcp::Application *App, char const *Theme, char const *extra_ui)
 		break;
 	case gcugtk::FullScreenWindowState:
 		gtk_window_fullscreen (window);
-		gtk_toggle_action_set_active (GTK_TOGGLE_ACTION (gtk_ui_manager_get_action (m_UIManager->GetUIManager (), "/MainMenu/ViewMenu/FullScreen")), true);
+		gtk_toggle_action_set_active (GTK_TOGGLE_ACTION (gtk_ui_manager_get_action (manager, "/MainMenu/ViewMenu/FullScreen")), true);
 		break;
 	default:
 		break;
 	}
 
-	GtkWidget *menu = gtk_ui_manager_get_widget (m_UIManager->GetUIManager (), "/MainMenu/FileMenu/Open");
+	GtkWidget *menu = gtk_ui_manager_get_widget (manager, "/MainMenu/FileMenu/Open");
 	GtkWidget *w = gtk_recent_chooser_menu_new_for_manager (App->GetRecentManager ());
 	gtk_recent_chooser_set_sort_type (GTK_RECENT_CHOOSER (w), GTK_RECENT_SORT_MRU);
 	GtkRecentFilter *filter = gtk_recent_filter_new ();
@@ -615,34 +585,35 @@ Window::Window (gcp::Application *App, char const *Theme, char const *extra_ui)
 	gtk_widget_show_all (item);
 	gtk_menu_shell_insert (GTK_MENU_SHELL (gtk_widget_get_parent (menu)), item, 3);
 
-	bar = gtk_ui_manager_get_widget (m_UIManager->GetUIManager (), "/MainMenu");
-	gtk_box_pack_start (GTK_BOX (vbox), bar, false, false, 0);
-	bar = gtk_ui_manager_get_widget (m_UIManager->GetUIManager (), "/MainToolbar");
-	gtk_box_pack_start (GTK_BOX (vbox), bar, false, false, 0);
+	bar = gtk_ui_manager_get_widget (manager, "/MainMenu");
+	gtk_container_add (GTK_CONTAINER (grid), bar);
+	bar = gtk_ui_manager_get_widget (manager, "/MainToolbar");
+	gtk_container_add (GTK_CONTAINER (grid), bar);
 	m_Document = new Document (App, true, this);
 	if (Theme)
 		m_Document->SetTheme (TheThemeManager.GetTheme (Theme));
 	gtk_window_set_title (window, m_Document->GetTitle ());
 	w = m_Document->GetView ()->CreateNewWidget ();
+	g_object_set (G_OBJECT (w), "expand", true, NULL);
 	GtkScrolledWindow* scroll = (GtkScrolledWindow*) gtk_scrolled_window_new (NULL, NULL);
 	gtk_scrolled_window_set_policy (scroll, GTK_POLICY_AUTOMATIC, GTK_POLICY_AUTOMATIC);
 	gtk_scrolled_window_set_shadow_type (scroll, GTK_SHADOW_IN);
 	gtk_scrolled_window_add_with_viewport (scroll, w);
 	gtk_widget_set_size_request (GTK_WIDGET (scroll), 408, 308);
 	gtk_widget_show (GTK_WIDGET (scroll));
-	gtk_box_pack_start (GTK_BOX (vbox), GTK_WIDGET (scroll), true, true, 0);
+	gtk_container_add (GTK_CONTAINER (grid), GTK_WIDGET (scroll));
 	m_Bar = gtk_statusbar_new ();
 	m_statusId = gtk_statusbar_get_context_id (GTK_STATUSBAR (m_Bar), "status");
 	gtk_statusbar_push (GTK_STATUSBAR (m_Bar), m_statusId, _("Ready"));
 	m_MessageId = 0;
-	gtk_box_pack_start (GTK_BOX (vbox), m_Bar, false, false, 0);
-		
-	g_signal_connect(GTK_OBJECT(window), "key_press_event", (GCallback)on_key_press, this);
-	g_signal_connect(GTK_OBJECT(window), "key_release_event", (GCallback)on_key_release, this);
+	gtk_container_add (GTK_CONTAINER (grid), m_Bar);
 
-	gtk_widget_set_sensitive (gtk_ui_manager_get_widget (m_UIManager->GetUIManager (), "/MainMenu/EditMenu/Copy"), false);
-	gtk_widget_set_sensitive (gtk_ui_manager_get_widget (m_UIManager->GetUIManager (), "/MainMenu/EditMenu/Cut"), false);
-	gtk_widget_set_sensitive (gtk_ui_manager_get_widget (m_UIManager->GetUIManager (), "/MainMenu/EditMenu/Erase"), false);
+	g_signal_connect (G_OBJECT(window), "key_press_event", (GCallback)on_key_press, this);
+	g_signal_connect (G_OBJECT(window), "key_release_event", (GCallback)on_key_release, this);
+
+	gtk_widget_set_sensitive (gtk_ui_manager_get_widget (manager, "/MainMenu/EditMenu/Copy"), false);
+	gtk_widget_set_sensitive (gtk_ui_manager_get_widget (manager, "/MainMenu/EditMenu/Cut"), false);
+	gtk_widget_set_sensitive (gtk_ui_manager_get_widget (manager, "/MainMenu/EditMenu/Erase"), false);
 	gtk_widget_show_all (GTK_WIDGET (window));
 	App->SetActiveDocument (m_Document);
 }
@@ -739,7 +710,7 @@ void Window::Zoom (double zoom)
 	else {
 		Dialog *pDialog = m_Document->GetDialog ("Zoom");
 		if (pDialog)
-			pDialog->Present (); 
+			pDialog->Present ();
 		else
 			new ZoomDlg (m_Document);
 	}
@@ -805,13 +776,6 @@ char const *Window::GetDefaultTitle ()
 	return _("GChemPaint");
 }
 
-void Window::ActivateActionWidget (char const *path, bool activate)
-{
-	GtkWidget *w = gtk_ui_manager_get_widget (m_UIManager->GetUIManager (), path);
-	if (w)
-		gtk_widget_set_sensitive (w, activate);
-}
-
 bool Window::VerifySaved ()
 {
 	if (!m_Document->GetDirty ())
