@@ -84,7 +84,7 @@ gcpSelectionTool::~gcpSelectionTool ()
 
 bool gcpSelectionTool::OnClicked ()
 {
-	gcp::Window *win = m_pView->GetDoc ()->GetWindow ();
+	gcp::Window *win = static_cast < gcp::Window * > (m_pView->GetDoc ()->GetWindow ());
 	if (m_pObject) {
 		Object* pObj = m_pObject->GetGroup ();
 		if (pObj)
@@ -264,7 +264,7 @@ void gcpSelectionTool::AddSelection (gcp::WidgetData* data)
 	gcp::WidgetData *d = m_pData;
 	m_pData = data;
 	m_pView = data->m_View;
-	gcp::Window *win = m_pView->GetDoc ()->GetWindow ();
+	gcp::Window *win = static_cast < gcp::Window * > (m_pView->GetDoc ()->GetWindow ());
 	if (m_pData->HasSelection()) {
 		GtkClipboard *clipboard = gtk_clipboard_get (GDK_SELECTION_PRIMARY);
 		m_pView->OnCopySelection (m_pData->Canvas, clipboard);
@@ -363,7 +363,11 @@ static void on_group (gcpSelectionTool* tool)
 void gcpSelectionTool::Group ()
 {
 	gcp::Document *pDoc = m_pView->GetDoc ();
-	new gcpGroupDlg (pDoc, NULL);
+	gcu::Dialog *dlg = pDoc->GetDialog ("group");
+	if (dlg)
+		dlg->Present ();
+	else
+		new gcpGroupDlg (pDoc, NULL);
 }
 
 void gcpSelectionTool::CreateGroup ()
